/**
 *
 * Copyright 2020 Tencent
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
'use strict';
const __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
  function adopt(value) {
    return value instanceof P ? value : new P((resolve) => {
      resolve(value);
    });
  }
  return new (P || (P = Promise))((resolve, reject) => {
    function fulfilled(value) {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    }
    function rejected(value) {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    }
    function step(result) {
      result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected);
    }
    step((generator = generator.apply(thisArg, _arguments || [])).next());
  });
};
const __importDefault = (this && this.__importDefault) || function (mod) {
  return (mod && mod.__esModule) ? mod : { default: mod };
};
Object.defineProperty(exports, '__esModule', { value: true });
const path_1 = __importDefault(require('path'));
const archiver_1 = __importDefault(require('archiver'));
const fs_1 = __importDefault(require('fs'));
function zipFile(src, dest) {
  return __awaiter(this, void 0, void 0, function* () {
    return new Promise((resolve, reject) => {
      // create a file to stream archive data to.
      const output = fs_1.default.createWriteStream(dest);
      const archive = archiver_1.default('zip', {
        zlib: { level: 9 },
      });
      output.on('close', () => {
        resolve();
      });
      archive.on('error', reject);
      archive.file(src, {
        name: path_1.default.basename(src),
      });
      archive.pipe(output);
      archive.finalize();
    });
  });
}
exports.zipFile = zipFile;
function zipDir(src, dest, ignore) {
  return __awaiter(this, void 0, void 0, function* () {
    return new Promise((resolve, reject) => {
      // create a file to stream archive data to.
      const output = fs_1.default.createWriteStream(dest);
      const archive = archiver_1.default('zip', {
        zlib: { level: 9 },
      });
      output.on('close', () => {
        resolve();
      });
      archive.on('error', reject);
      archive.glob('**/*', {
        cwd: src,
        ignore: ignore || [],
        dot: true,
      }, {});
      archive.pipe(output);
      archive.finalize();
    });
  });
}
exports.zipDir = zipDir;
